# Changelog

<!--next-version-placeholder-->

## v0.2.6 (2021-03-02)
### Fix
* Use python3 to build release package. ([`92f2070`](https://github.com/andrewjw/glowprom/commit/92f2070b4b0c2433c3fc1733dfa5121d8d93d980))
* Fake commit to test release via buildbot. ([`633d588`](https://github.com/andrewjw/glowprom/commit/633d5888a67e9af3fd1fcdaeb4a55031590bd42c))
* Add Docker badge (mostly to test buildbot release) ([`f206b62`](https://github.com/andrewjw/glowprom/commit/f206b6209c0330ab8fff59ec0897099aacab497e))
